==> ocstore25_6_20.zip: OcStore/Prgm/data/language/en-us/script/CS_peace_town_bakery.lua <==
function E0090()
    MNA()CMU("CS_Anzen")FAI(0)
end
function E0091()
    MNA()CMU("CS_Anzen")FAI(1)
end
function E0092()
    MNA()CMU("CS_Anzen")FAI(2)
end
function E0093()
    MNA()CMU("CS_Anzen")FAI(3)
end
function E0094()
    MNA()CMU("CS_Anzen")FAI(4)
end

function Door_GoPeaceTown()
    PRI()MM0()SOU("CS_011_door")ANP("Door_GoPeaceTown",0,1)FAO(2)TRA("CS_peace_town","E0090",27,31)
end

function Pastrychef1()
    if(ITJ("Translator")) then
        if(FLJ("HoneyGive")) then
            KEY()
            MS3("\nThank you for helping me make desserts again.")NOD()
        elseif(FLJ("SearchHoney")) then
            if(ITJ("Honey")) then
                KEY()
                GIT("Honey")
                FAC("jack_normal")MS3("\nWe brought the honey.")NOD()CLR()
                GIT()
                ITS("Honey")
                FAC()CAT("Thank you! My little hreos,")NOD()
                CAT("\nPlease wait a moment.")NOD()CLO()
                FAO(0)
                WAI(32)
                FAI(2)
                WAI(32)
                GIT("Doughnut")
                MS3("It's done! - Giant Honey Doughnut -")NOD()
                ITP("Doughnut")
                SOU("CS_038_get_item")
                CAT("\nThis is my thanks to you.")NOD()
                FLP("HoneyGive")
                MSR("BringHoneyToBaker","BringDoughnutToGunsmith")
            elseif(ITJ("Honeycomb")) then
                KEY()
                GIT("Honeycomb")
                MS3("Wow! Is this a wild honeycomb?")NOD()
                CAT("\nIt looks really fresh.")NOD()CLR()
                FAC("jack_normal")CAT("We'll process it")
                CAT("\nand bring it back to you.")NOD()CLR()
            else
                KEY()
                MS3("If we had some honey")
                CAT("\nI could make desserts again.")NOD()
            end
        elseif(FLJ("BringSomeDesserts")) then
            KEY()
            FAC("jack_normal")MS3("Master, do you have any")
            CAT("\ndesserts for sale?")NOD()CLR()
            FAC()CAT("As for desserts, due to lack of honey")
            CAT("\nI haven't been able to make them") 
            CAT("\nfor some time.")NOD()CLR()
            CAT("\nAs you can see,")NOD()
            CAT("there's only bread left...")NOD()CLR()
            CAT("The next shipment of honey")
            CAT("\nwon't arrive for another month.")NOD()CLR()
            FAC("jack_><")CAT("\n(We can't wait that long)")NOD()CLR()
            FAC("jack_normal")CAT("If we could get you ")
            CAT("\nsome honey sooner,")NOD()
            CAT("\nyou could make desserts again,") 
            CAT("\nright Master?")NOD()CLR()
            FAC()CAT("Yes, if you could bring some")
            CAT("\nI would be truly grateful.")NOD()CLR()
            FAC("jack_normal")CAT("\nI understand.")NOD()
            FLP("SearchHoney")
            MSR("BringSomeDessert","LackOfHoney")
        else
            KEY()
            MS3("Hello, little ones.")NOD()
            CAT("\nAre you here to buy bread?")NOD()CLR()
            FAC("jack_normal")CAT("\nThanks, we've already eaten.")NOD()
        end
    else
        KEY()
        MS3("\n......")NOD()
    end
end

function CheckBread()
    KEY()
    MS3("\nHere's some bread.")NOD()
end

==> ocstore25_7_23.zip: OcStore/Prgm/data/language/en-us/script/CS_peace_town_bakery.lua <==
function E0090()
    MNA()CMU("CS_Anzen")FAI(0)
end
function E0091()
    MNA()CMU("CS_Anzen")FAI(1)
end
function E0092()
    MNA()CMU("CS_Anzen")FAI(2)
end
function E0093()
    MNA()CMU("CS_Anzen")FAI(3)
end
function E0094()
    MNA()CMU("CS_Anzen")FAI(4)
end

function Door_GoPeaceTown()
    PRI()MM0()SOU("CS_011_door")ANP("Door_GoPeaceTown",0,1)FAO(2)TRA("CS_peace_town","E0090",27,31)
end

function Pastrychef1()
    if(ITJ("Translator")) then
        if(FLJ("HoneyGive")) then
            KEY()
            MS3("\nThank you for helping me make desserts again.")NOD()
        elseif(FLJ("SearchHoney")) then
            if(ITJ("Honey")) then
                KEY()
                GIT("Honey")
                FAC("jack_normal")MS3("\nWe brought the honey.")NOD()CLR()
                GIT()
                ITS("Honey")
                FAC()CAT("Thank you! My little heros,")NOD()
                CAT("\nPlease wait a moment.")NOD()CLO()
                FAO(0)
                WAI(32)
                FAI(2)
                WAI(32)
                GIT("Doughnut")
                MS3("It's done! - Giant Honey Doughnut -")NOD()
                ITP("Doughnut")
                SOU("CS_038_get_item")
                CAT("\nThis is my thanks to you.")NOD()
                FLP("HoneyGive")
                MSR("BringHoneyToBaker","BringDoughnutToGunsmith")
            elseif(ITJ("Honeycomb")) then
                KEY()
                GIT("Honeycomb")
                MS3("Wow! Is this a wild honeycomb?")NOD()
                CAT("\nIt looks really fresh.")NOD()CLR()
                FAC("jack_normal")CAT("We'll process it")
                CAT("\nand bring it back to you.")NOD()CLR()
            else
                KEY()
                MS3("If we had some honey")
                CAT("\nI could make desserts again.")NOD()
            end
        elseif(FLJ("BringSomeDesserts")) then
            KEY()
            FAC("jack_normal")MS3("Master, do you have any")
            CAT("\ndesserts for sale?")NOD()CLR()
            FAC()CAT("As for desserts, due to lack of honey")
            CAT("\nI haven't been able to make them") 
            CAT("\nfor some time.")NOD()CLR()
            CAT("\nAs you can see,")NOD()
            CAT("there's only bread left...")NOD()CLR()
            CAT("The next shipment of honey")
            CAT("\nwon't arrive for another month.")NOD()CLR()
            FAC("jack_><")CAT("\n(We can't wait that long)")NOD()CLR()
            FAC("jack_normal")CAT("If we could get you ")
            CAT("\nsome honey sooner,")NOD()
            CAT("\nyou could make desserts again,") 
            CAT("\nright Master?")NOD()CLR()
            FAC()CAT("Yes, if you could bring some")
            CAT("\nI would be truly grateful.")NOD()CLR()
            FAC("jack_normal")CAT("\nI understand.")NOD()
            FLP("SearchHoney")
            MSR("BringSomeDessert","LackOfHoney")
        else
            KEY()
            MS3("Hello, little ones.")NOD()
            CAT("\nAre you here to buy bread?")NOD()CLR()
            FAC("jack_normal")CAT("\nThanks, we've already eaten.")NOD()
        end
    else
        KEY()
        MS3("\n......")NOD()
    end
end

function CheckBread()
    KEY()
    MS3("\nHere's some bread.")NOD()
end
